All of lore.kernel.org
 help / color / mirror / Atom feed
From: Geliang Tang <geliang.tang@suse.com>
To: mptcp@lists.linux.dev
Cc: Geliang Tang <geliang.tang@suse.com>
Subject: [PATCH mptcp-next v5 5/5] selftests: mptcp: set ip_mptcp in command line
Date: Thu, 13 Jan 2022 23:08:39 +0800	[thread overview]
Message-ID: <01aa080335478b774fe99f83167fcbec53d86302.1642086296.git.geliang.tang@suse.com> (raw)
In-Reply-To: <cover.1642086296.git.geliang.tang@suse.com>

This patch added a command line option '-i' for mptcp_join.sh to use
'ip mptcp' commands instead of using 'pm_nl_ctl' commands to deal with
PM netlink.

Signed-off-by: Geliang Tang <geliang.tang@suse.com>
---
 tools/testing/selftests/net/mptcp/mptcp_join.sh | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

diff --git a/tools/testing/selftests/net/mptcp/mptcp_join.sh b/tools/testing/selftests/net/mptcp/mptcp_join.sh
index 529765f3ab5e..193fa5adb9ad 100755
--- a/tools/testing/selftests/net/mptcp/mptcp_join.sh
+++ b/tools/testing/selftests/net/mptcp/mptcp_join.sh
@@ -2203,6 +2203,7 @@ usage()
 	echo "  -u userspace_tests"
 	echo "  -c capture pcap files"
 	echo "  -C enable data checksum"
+	echo "  -i use ip mptcp"
 	echo "  -h help"
 }
 
@@ -2224,9 +2225,12 @@ for arg in "$@"; do
 	if [[ "${arg}" =~ ^"-"[0-9a-zA-Z]*"C"[0-9a-zA-Z]*$ ]]; then
 		checksum=1
 	fi
+	if [[ "${arg}" =~ ^"-"[0-9a-zA-Z]*"i"[0-9a-zA-Z]*$ ]]; then
+		ip_mptcp=1
+	fi
 
-	# exception for the capture/checksum options, the rest means: a part of the tests
-	if [ "${arg}" != "-c" ] && [ "${arg}" != "-C" ]; then
+	# exception for the capture/checksum/ip_mptcp options, the rest means: a part of the tests
+	if [ "${arg}" != "-c" ] && [ "${arg}" != "-C" ] && [ "${arg}" != "-i" ]; then
 		do_all_tests=0
 	fi
 done
@@ -2236,7 +2240,7 @@ if [ $do_all_tests -eq 1 ]; then
 	exit $ret
 fi
 
-while getopts 'fesltra64bpkdmuchCS' opt; do
+while getopts 'fesltra64bpkdmuchCSi' opt; do
 	case $opt in
 		f)
 			subflows_tests
@@ -2290,6 +2294,8 @@ while getopts 'fesltra64bpkdmuchCS' opt; do
 			;;
 		C)
 			;;
+		i)
+			;;
 		h | *)
 			usage
 			;;
-- 
2.31.1


  parent reply	other threads:[~2022-01-13 15:10 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-01-13 15:08 [PATCH mptcp-next v2 0/3] set_flags port support Geliang Tang
2022-01-13 15:08 ` [PATCH mptcp-next v2 1/3] mptcp: allow to use port and non-signal in set_flags Geliang Tang
2022-01-13 15:08 ` [PATCH mptcp-next v2 2/3] selftests: mptcp: add the port argument for set_flags Geliang Tang
2022-01-13 15:08 ` [PATCH mptcp-next v2 3/3] selftests: mptcp: add backup with port testcase Geliang Tang
2022-01-14  1:13   ` Mat Martineau
2022-01-13 15:08 ` [PATCH mptcp-next v5 0/5] use 'ip mptcp' in selftests Geliang Tang
2022-01-13 15:08   ` [PATCH mptcp-next v5 1/5] selftests: mptcp: add ip mptcp wrappers Geliang Tang
2022-01-13 15:08   ` [PATCH mptcp-next v5 2/5] selftests: mptcp: new approach of getting ID Geliang Tang
2022-01-13 15:08   ` [PATCH mptcp-next v5 3/5] selftests: mptcp: add wrapper for showing addrs Geliang Tang
2022-01-13 15:08   ` [PATCH mptcp-next v5 4/5] selftests: mptcp: add wrapper for setting flags Geliang Tang
2022-01-14  1:22     ` Mat Martineau
2022-01-13 15:08   ` Geliang Tang [this message]
2022-01-14  1:27   ` [PATCH mptcp-next v5 0/5] use 'ip mptcp' in selftests Mat Martineau

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=01aa080335478b774fe99f83167fcbec53d86302.1642086296.git.geliang.tang@suse.com \
    --to=geliang.tang@suse.com \
    --cc=mptcp@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.